/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import React from 'react';
import PropTypes from 'prop-types';
import pure from 'recompose/pure';
import Chip from './Chip';

var tooltipStyle = {
    display: 'flex',
    alignItems: 'center'
};

var textStyle = {
    whiteSpace: 'pre',
    marginLeft: 7
};

var BasicTooltip = function BasicTooltip(_ref) {
    var id = _ref.id,
        value = _ref.value,
        enableChip = _ref.enableChip,
        color = _ref.color;
    return React.createElement(
        'div',
        { style: tooltipStyle },
        enableChip && React.createElement(Chip, { color: color }),
        value !== undefined ? React.createElement(
            'span',
            { style: textStyle },
            id,
            ': ',
            React.createElement(
                'strong',
                null,
                value
            )
        ) : React.createElement(
            'span',
            { style: textStyle },
            id
        )
    );
};

BasicTooltip.propTypes = {
    id: PropTypes.oneOfType([PropTypes.string, PropTypes.number]).isRequired,
    value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    enableChip: PropTypes.bool.isRequired,
    color: PropTypes.string
};

BasicTooltip.defaultProps = {
    enableChip: false
};

export default pure(BasicTooltip);